@@ -138,15 +138,16 @@ class DumpResultSqlite(DumpResult):
 		update_keys = list(self.to_update.keys())
 
 		for key in update_keys:
+			object_id = self.targets[key]
 			# get previous saved copy:
-			old_key, lines, parents = self.get_obj_from_db(key)
+			old_key, lines, parents = self.get_obj_from_db(object_id)
 
 			# update that copy
 			self.update_in_db(
 				(
-					self.targets[key],
+					object_id,
 					lines + self.to_update[key],
-					parents + self.to_update_parents[key]
+					parents.update( self.to_update_parents[key] )
 				)
 			)
 			del self.to_update[key]
@@ -174,7 +175,7 @@ class DumpResultSqlite(DumpResult):
 
 			if article_name not in self.to_update:
 				self.to_update[article_name] = []
-				self.to_update_parents[article_name] = []
+				self.to_update_parents[article_name] = set()
 			
 			self.to_update[article_name].append(
 				(line, list(self.replace_links_with_index(links)))
@@ -182,7 +183,7 @@ class DumpResultSqlite(DumpResult):
 			cat_links = [self.targets[link[0]] for link in links if link[0].startswith("Category")]
 
 			if len(cat_links) > 0:
-				self.to_update_parents[article_name].append(
+				self.to_update_parents[article_name].update(
 					cat_links
 				)
 
