@@ -36,7 +36,7 @@ def create_schema(conn, schema, table_name):
         )
 
     def get_obj_from_db(key):
-        cursor.execute(select_string, (key))
+        cursor.execute(select_string, (key,))
         data = cursor.fetchone()
         return data
 
